# PyUpgrader

![PyPI - Status](https://img.shields.io/pypi/status/pyupgrader)
![PyPI - Version](https://img.shields.io/pypi/v/pyupgrader)
![PyLint](https://github.com/Trogiken/PyUpgrader/actions/workflows/pylint.yml/badge.svg?branch=master)
![CodeQL](https://github.com/Trogiken/PyUpgrader/actions/workflows/codeql.yml/badge.svg?branch=master)
![PyTest](https://github.com/Trogiken/PyUpgrader/actions/workflows/python-package.yml/badge.svg?branch=master)

Python library that keeps project files updated on client machines

PyPi page can be found [here](https://pypi.org/project/pyupgrader/)  
Find the documentation [here](https://github.com/Trogiken/PyUpgrader/wiki/)
